==> haskell-servant-0.20.3.0-36-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-servant.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 servant
version:              0.20.3.0
visibility:           public
id:                   servant-0.20.3.0-lF82iptA2PDz2IIzgvq7U
key:                  servant-0.20.3.0-lF82iptA2PDz2IIzgvq7U
license:              BSD-3-Clause
copyright:
    2014-2016 Zalora South East Asia Pte Ltd, 2016-2019 Servant Contributors

maintainer:           haskell-servant-maintainers@googlegroups.com
author:               Servant Contributors
homepage:             http://docs.servant.dev/
synopsis:             A family of combinators for defining webservices APIs
description:
    A family of combinators for defining webservices APIs and serving them
    .
    You can learn about the basics in the <http://docs.servant.dev/en/stable/tutorial/index.html tutorial>.
    .
    <https://github.com/haskell-servant/servant/blob/master/servant/CHANGELOG.md CHANGELOG>

category:             Servant, Web
abi:                  939b5a2304867068e3d9cc5b0d98a367
exposed:              True
exposed-modules:
    Servant.API Servant.API.Alternative Servant.API.BasicAuth
    Servant.API.Capture Servant.API.ContentTypes
    Servant.API.Description Servant.API.Empty
    Servant.API.Experimental.Auth Servant.API.Fragment
    Servant.API.Generic Servant.API.Header Servant.API.Host
    Servant.API.HttpVersion Servant.API.IsSecure Servant.API.Modifiers
    Servant.API.MultiVerb Servant.API.NamedRoutes
    Servant.API.QueryParam Servant.API.QueryString Servant.API.Range
    Servant.API.Raw Servant.API.RemoteHost Servant.API.ReqBody
    Servant.API.ResponseHeaders Servant.API.ServerSentEvents
    Servant.API.Status Servant.API.Stream Servant.API.Sub
    Servant.API.TypeErrors Servant.API.TypeLevel
    Servant.API.TypeLevel.List Servant.API.UVerb
    Servant.API.UVerb.Union Servant.API.Vault Servant.API.Verbs
    Servant.API.WithNamedContext Servant.API.WithResource Servant.Links
    Servant.Test.ComprehensiveAPI Servant.Types.Internal.Response
    Servant.Types.SourceT

import-dirs:          /usr/lib/ghc-9.4.8/site-local/servant-0.20.3.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/servant-0.20.3.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/servant-0.20.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-servant
hs-libraries:         HSservant-0.20.3.0-lF82iptA2PDz2IIzgvq7U
depends:
    QuickCheck-2.15.0.1-K2FdhpAloErGP21S0B8fgw
    aeson-2.1.2.1-6h5MFvBT17H5yplsTy4ABm
    attoparsec-0.14.4-8oph4y3j0I1GXQUqU3wi8s base-4.17.2.1
    bifunctors-5.6.2-5mu6fFOI9gvG6gcJfurJCW bytestring-0.11.5.3
    case-insensitive-1.2.1.0-rTys5srD4l50KQCiQKWYt
    constraints-0.14.2-8xxeROjVDbNF7eB7brUgc7 containers-0.6.7
    deepseq-1.4.8.0 generics-sop-0.5.1.3-1cdm4H81rvrYJuJwoMQFY
    http-api-data-0.6.1-8c1eam2iy3S1H0ucz1wNHM
    http-media-0.8.1.1-80YSf7aABZX5CeY9t1WlUN
    http-types-0.12.4-8KsSLLTB3zVcsjL7f3kez
    mmorph-1.2.1-Dj3j5073UbJL5k7iF3E3ML mtl-2.2.2
    network-uri-2.6.4.2-60V3uLcyBv8HHhnYdb8knn
    singleton-bool-0.1.8-20VzeYntw6i2g6Ao11tIZX
    sop-core-0.5.0.2-6A7lf58QPy2GZuvhMdgskj text-2.0.2
    transformers-0.5.6.2 vault-0.3.1.5-FlafIjEMT5q6GDikkGAyLI

haddock-interfaces:   /usr/share/doc/haskell-servant/html/servant.haddock
haddock-html:         /usr/share/doc/haskell-servant/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-servant-0.20.3.0-37-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-servant.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 servant
version:              0.20.3.0
visibility:           public
id:                   servant-0.20.3.0-GBkcR4cT3t0984tVDpOSuZ
key:                  servant-0.20.3.0-GBkcR4cT3t0984tVDpOSuZ
license:              BSD-3-Clause
copyright:
    2014-2016 Zalora South East Asia Pte Ltd, 2016-2019 Servant Contributors

maintainer:           haskell-servant-maintainers@googlegroups.com
author:               Servant Contributors
homepage:             http://docs.servant.dev/
synopsis:             A family of combinators for defining webservices APIs
description:
    A family of combinators for defining webservices APIs and serving them
    .
    You can learn about the basics in the <http://docs.servant.dev/en/stable/tutorial/index.html tutorial>.
    .
    <https://github.com/haskell-servant/servant/blob/master/servant/CHANGELOG.md CHANGELOG>

category:             Servant, Web
abi:                  fab184024e147480979fdf4bbe104eab
exposed:              True
exposed-modules:
    Servant.API Servant.API.Alternative Servant.API.BasicAuth
    Servant.API.Capture Servant.API.ContentTypes
    Servant.API.Description Servant.API.Empty
    Servant.API.Experimental.Auth Servant.API.Fragment
    Servant.API.Generic Servant.API.Header Servant.API.Host
    Servant.API.HttpVersion Servant.API.IsSecure Servant.API.Modifiers
    Servant.API.MultiVerb Servant.API.NamedRoutes
    Servant.API.QueryParam Servant.API.QueryString Servant.API.Range
    Servant.API.Raw Servant.API.RemoteHost Servant.API.ReqBody
    Servant.API.ResponseHeaders Servant.API.ServerSentEvents
    Servant.API.Status Servant.API.Stream Servant.API.Sub
    Servant.API.TypeErrors Servant.API.TypeLevel
    Servant.API.TypeLevel.List Servant.API.UVerb
    Servant.API.UVerb.Union Servant.API.Vault Servant.API.Verbs
    Servant.API.WithNamedContext Servant.API.WithResource Servant.Links
    Servant.Test.ComprehensiveAPI Servant.Types.Internal.Response
    Servant.Types.SourceT

import-dirs:          /usr/lib/ghc-9.4.8/site-local/servant-0.20.3.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/servant-0.20.3.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/servant-0.20.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-servant
hs-libraries:         HSservant-0.20.3.0-GBkcR4cT3t0984tVDpOSuZ
depends:
    QuickCheck-2.15.0.1-1pOwhmMeliZCxioVyv9M89
    aeson-2.1.2.1-9rGsBPhyshTKvPzkopJx8r
    attoparsec-0.14.4-4euoXrooDbuLZe6Xn3rp2d base-4.17.2.1
    bifunctors-5.6.2-38eX83A5YbAKDBBe87o47d bytestring-0.11.5.3
    case-insensitive-1.2.1.0-4HYxnyEi2mnBK2ectdARDN
    constraints-0.14.2-4ZbFwmDhyTJ9uchmlBvQF0 containers-0.6.7
    deepseq-1.4.8.0 generics-sop-0.5.1.3-1cdm4H81rvrYJuJwoMQFY
    http-api-data-0.6.1-1ULNIzihZGtK3yt1euW535
    http-media-0.8.1.1-DrLbjjJ2N3xGFqwjVRuqRd
    http-types-0.12.4-5kbj0Cv0rp8HNRwQfelhRA
    mmorph-1.2.1-Dj3j5073UbJL5k7iF3E3ML mtl-2.2.2
    network-uri-2.6.4.2-FfZCDPDUWea9JZl5JGUmKF
    singleton-bool-0.1.8-7ikkAPvQzaLB3gwIp59x8n
    sop-core-0.5.0.2-6A7lf58QPy2GZuvhMdgskj text-2.0.2
    transformers-0.5.6.2 vault-0.3.1.5-3IzrwhxRuPjKoW7XW0Zg3M

haddock-interfaces:   /usr/share/doc/haskell-servant/html/servant.haddock
haddock-html:         /usr/share/doc/haskell-servant/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
